/////////////////////////////////////////////////////////////////////////////
// Include files
// These lines allow us to use code routines (libraries) from other files,
// so that we don't have to write everything by ourselves.
/////////////////////////////////////////////////////////////////////////////

#include <p18lf25k22.h>     // This file includes definitions for all of the
                           // registers on our chip

/////////////////////////////////////////////////////////////////////////////
// Pragma statements
// These lines tell the microcontroller what configuration to use when it
// when it turns on. The most important part for now is to tell the
// microcontroller what to use for a clock input.
/////////////////////////////////////////////////////////////////////////////

// Use the internal oscillator as a clock
#pragma config FOSC = INTIO67

// Configure it to run at 16 MHz
#pragma config PLLCFG = OFF

// Make sure that the internal watchdog timer is off. The watchdog is a
// a special feature of the processor, that runs separately from the main
// program
#pragma config WDTEN = OFF
#pragma config PBADEN = OFF


// Set up some defines for bit masks for the motor control lines
#define LEFTMOTOR_C1 0x01
#define LEFTMOTOR_C2 0x02
#define RIGHTMOTOR_C1 0x04
#define RIGHTMOTOR_C2 0x08

#define numSteps 400

/////////////////////////////////////////////////////////////////////////////
// Function declarations
// Declare any user functions that you want to use here
/////////////////////////////////////////////////////////////////////////////
void main (void);
void setup(void);
void loop(void);

int C1states[4] = {0x00, 0x01, 0x01, 0x00};
int C2states[4] = {0x02, 0x02, 0x00, 0x00};
int n = 0;

int state = 0;
int direction = 1;
int stepCount =0;

/////////////////////////////////////////////////////////////////////////////
// Function definitions
// Define any user functions that you want to use here
/////////////////////////////////////////////////////////////////////////////

// The main() function is where the program 'starts' when the microcontroller
// is turned on. For this project, we will use it to call setup() and loop()
// functions, then use those similar to an Arduino sketch.

void main (void)
{
   // Call the setup function once to put everything in order
   setup();

   // Then call the loop() function over and over
   while (1)
   {
       loop();
   }
}

void turnMotor() {
   unsigned int count;
   PORTA = C1states[state] | C2states[state];
   for( count = 0; count < 2000; count++) {}
}

// This function is called once, when the microcontroller is turned on.
void setup(void) {
   // Configure the oscillator to use a 16 MHz input.
   OSCCONbits.IRCF = 111;

   // Set all of the pins on Port A to be outputs,
   // Cleared bits are outputs.
   TRISA = 0x00;
   PORTA = 0x00;

   // Set up buttons as inputs
   TRISB = 0x0f;

}

// This function is called repeatedly
void loop(void) {

   if ((stepCount % numSteps) == 0) {
       direction = -direction;
   }
   stepCount += direction;
   state = stepCount %4;
   if (state < 0) {
       state = -state;
   }
   turnMotor();

}

